@@ -1,19 +1,23 @@
 from __future__ import unicode_literals
 
+from six.moves import urllib_parse as urlparse
 import os
 import collections
+import requests
 
 import six
 import json
 import yaml
 
+from flex.context_managers import ErrorCollection
+from flex.exceptions import ValidationError
 from flex.serializers.core import (
     SwaggerSerializer,
     SchemaSerializer,
 )
 from flex.serializers.definitions import SwaggerDefinitionsSerializer
 from flex.utils import prettify_errors
-
+from flex.validation.request import generate_request_validator
 from flex.validation.response import generate_response_validator
 
 
@@ -31,24 +35,31 @@ def load_source(source):
     """
     if isinstance(source, collections.Mapping):
         return source
-
     elif hasattr(source, 'read') and callable(source.read):
         raw_source = source.read()
     elif os.path.exists(os.path.expanduser(str(source))):
         with open(os.path.expanduser(str(source)), 'r') as source_file:
             raw_source = source_file.read()
     elif isinstance(source, six.string_types):
-        raw_source = source
+        parts = urlparse.urlparse(source)
+        if parts.scheme and parts.netloc:
+            response = requests.get(source)
+            if isinstance(response.content, six.binary_type):
+                raw_source = six.text_type(response.content, encoding='utf-8')
+            else:
+                raw_source = response.content
+        else:
+            raw_source = source
 
     try:
         try:
-            return yaml.load(raw_source)
-        except yaml.scanner.ScannerError:
+            return json.loads(raw_source)
+        except ValueError:
             pass
 
         try:
-            return json.loads(raw_source)
-        except ValueError:
+            return yaml.load(raw_source)
+        except (yaml.scanner.ScannerError, yaml.parser.ParserError):
             pass
     except NameError:
         pass
@@ -63,12 +74,11 @@ def parse(raw_schema):
         data=raw_schema,
     )
     if not definitions_serializer.is_valid():
-
         message = "Swagger definitions did not validate:\n\n"
         message += prettify_errors(definitions_serializer.errors)
         raise ValueError(message)
 
-    swagger_definitions = definitions_serializer.object
+    swagger_definitions = definitions_serializer.save()
 
     swagger_serializer = SwaggerSerializer(
         swagger_definitions,
@@ -81,7 +91,7 @@ def parse(raw_schema):
         message += prettify_errors(swagger_serializer.errors)
         raise ValueError(message)
 
-    return swagger_serializer.object
+    return swagger_serializer.save()
 
 
 def load(target):
@@ -103,12 +113,22 @@ def validate(schema, target=None, **kwargs):
     if not schema_serializer.is_valid():
         message = "JSON Schema did not validate:\n\n"
         message += prettify_errors(schema_serializer.errors)
-        raise ValueError(message)
+        raise ValidationError(message)
 
     if target is not None:
         validator = schema_serializer.save()
         validator(target)
 
 
-def ResponseValidator(schema):
-    return generate_response_validator(schema)
+def validate_api_call(schema, request, response):
+    with ErrorCollection() as errors:
+        try:
+            operation_definition = generate_request_validator(schema, inner=True)(request)
+        except ValidationError as err:
+            errors['request'].add_error(err.messages or getattr(err, 'detail'))
+            return
+
+        try:
+            generate_response_validator(operation_definition, schema, inner=True)(response)
+        except ValidationError as err:
+            errors['response'].add_error(err.messages or getattr(err, 'detail'))
